@@ -2,6 +2,7 @@ import asyncio
 import os
 import time
 from abc import ABCMeta, abstractmethod
+from asyncio import Future
 from collections import defaultdict, Counter
 from ssl import SSLContext
 from typing import List, Optional, Tuple, Dict, NamedTuple, Union, Set
@@ -24,21 +25,22 @@ from bxcommon.network.abstract_socket_connection_protocol import AbstractSocketC
 from bxcommon.network.ip_endpoint import IpEndpoint
 from bxcommon.network.peer_info import ConnectionPeerInfo
 from bxcommon.network.socket_connection_state import SocketConnectionState
+from bxcommon.services import sdn_http_service
 from bxcommon.services.broadcast_service import BroadcastService, \
     BroadcastOptions
 from bxcommon.services.threaded_request_service import ThreadedRequestService
 from bxcommon.services.transaction_service import TransactionService
 from bxcommon.utils import memory_utils, convert, performance_utils
-from bxcommon.utils.alarm_queue import AlarmQueue
+from bxcommon.utils.alarm_queue import AlarmQueue, AlarmId
 from bxcommon.utils.blockchain_utils import bdn_tx_to_bx_tx
 from bxcommon.common_opts import CommonOpts
-from bxcommon.utils.object_hash import Sha256Hash
 from bxcommon.utils.stats.block_statistics_service import block_stats
 from bxcommon.utils.stats.memory_statistics_service import memory_statistics
 from bxcommon.utils.stats.node_info_service import node_info_statistics
 from bxcommon.utils.stats.node_statistics_service import node_stats_service
 from bxcommon.utils.stats.throughput_service import throughput_statistics
 from bxcommon.utils.stats.transaction_statistics_service import tx_stats
+from bxcommon.utils.transaction_short_id_buckets import TransactionShortIdBuckets
 from bxutils import log_messages
 from bxutils import logging
 from bxutils.exceptions.connection_authentication_error import \
@@ -48,6 +50,7 @@ from bxutils.services.node_ssl_service import NodeSSLService
 from bxutils.ssl.extensions import extensions_factory
 from bxutils.ssl.ssl_certificate_type import SSLCertificateType
 
+
 logger = logging.get_logger(__name__)
 memory_logger = logging.get_logger(LogRecordType.BxMemory, __name__)
 performance_troubleshooting_logger = logging.get_logger(LogRecordType.PerformanceTroubleshooting, __name__)
@@ -123,17 +126,15 @@ class AbstractNode:
         # this way can verify if node lost connection to requested relay.
 
         self.last_sync_message_received_by_network: Dict[int, float] = {}
-        self.network_synced: Dict[int, bool] = defaultdict(lambda: False)
 
         self.start_sync_time: Optional[float] = None
         self.sync_metrics: Dict[int, Counter] = defaultdict(Counter)
+        self.sync_short_id_buckets: Dict[int, TransactionShortIdBuckets] = defaultdict(TransactionShortIdBuckets)
 
         opts.has_fully_updated_tx_service = False
 
-        self._check_sync_relay_connections_alarm_id = self.alarm_queue.register_alarm(
-            constants.LAST_MSG_FROM_RELAY_THRESHOLD_S, self._check_sync_relay_connections)
-        self._transaction_sync_timeout_alarm_id = self.alarm_queue.register_alarm(
-            constants.TX_SERVICE_CHECK_NETWORKS_SYNCED_S, self._transaction_sync_timeout)
+        self.check_sync_relay_connections_alarm_id: Optional[AlarmId] = None
+        self.transaction_sync_timeout_alarm_id: Optional[AlarmId] = None
 
         self.requester = ThreadedRequestService(
             # pyre-fixme[16]: `Optional` has no attribute `name`.
@@ -164,8 +165,32 @@ class AbstractNode:
     def get_broadcast_service(self) -> BroadcastService:
         pass
 
-    @abstractmethod
-    def send_request_for_relay_peers(self):
+    def sync_and_send_request_for_relay_peers(self, network_num: int) -> int:
+        """
+        Requests potential relay peers from SDN. Merges list with provided command line relays.
+
+        This function retrieves from the SDN potential_relay_peers_by_network
+        Then it try to ping for each relay (timeout of 2 seconds). The ping is done in parallel
+        Once there are ping result, it calculate the best relay and decides if need to switch relays
+
+        The above can take time, so the functions is split into several internal functions and use the thread pool
+        not to block the main thread.
+        """
+
+        self.requester.send_threaded_request(
+            sdn_http_service.fetch_potential_relay_peers_by_network,
+            self.opts.node_id,
+            network_num,
+            # pyre-fixme[6]: Expected `Optional[Callable[[Future[Any]], Any]]` for 4th parameter `done_callback`
+            #  to call `send_threaded_request` but got `BoundMethod[Callable(_process_blockchain_network_from_sdn)
+            #  [[Named(self, AbstractRelayConnection), Named(get_blockchain_network_future, Future[Any])], Any],
+            #  AbstractRelayConnection]`.
+            done_callback=self.process_potential_relays_from_sdn
+        )
+
+        return constants.CANCEL_ALARMS
+
+    def process_potential_relays_from_sdn(self, get_potential_relays_future: Future):
         pass
 
     @abstractmethod
@@ -173,7 +198,9 @@ class AbstractNode:
         pass
 
     @abstractmethod
-    def on_failed_connection_retry(self, ip: str, port: int, connection_type: ConnectionType) -> None:
+    def on_failed_connection_retry(
+        self, ip: str, port: int, connection_type: ConnectionType, connection_state: ConnectionState
+    ) -> None:
         pass
 
     def connection_exists(
@@ -493,11 +520,13 @@ class AbstractNode:
         return memory_statistics.flush_info()
 
     def set_node_config_opts_from_sdn(self, opts: CommonOpts) -> None:
-        blockchain_networks: List[BlockchainNetworkModel] = opts.blockchain_networks
-        for blockchain_network in blockchain_networks:
-            tx_stats.configure_network(blockchain_network.network_num,
-                                       blockchain_network.tx_percent_to_log_by_hash,
-                                       blockchain_network.tx_percent_to_log_by_sid)
+        blockchain_networks: Dict[int, BlockchainNetworkModel] = opts.blockchain_networks
+        for blockchain_network in blockchain_networks.values():
+            tx_stats.configure_network(
+                blockchain_network.network_num,
+                blockchain_network.tx_percent_to_log_by_hash,
+                blockchain_network.tx_percent_to_log_by_sid
+            )
         bdn_tx_to_bx_tx.init(blockchain_networks)
 
     def dump_memory_usage(self):
@@ -529,16 +558,20 @@ class AbstractNode:
     async def init(self) -> None:
         self.requester.start()
 
-    def handle_connection_closed(self, should_retry: bool, peer_info: ConnectionPeerInfo) -> None:
+    def handle_connection_closed(
+        self, should_retry: bool, peer_info: ConnectionPeerInfo, connection_state: ConnectionState
+    ) -> None:
         self.pending_connection_attempts.discard(peer_info)
         peer_ip, peer_port = peer_info.endpoint
         connection_type = peer_info.connection_type
         if should_retry and self.continue_retrying_connection(peer_ip, peer_port, connection_type):
-            self.alarm_queue.register_alarm(self._get_next_retry_timeout(peer_ip, peer_port),
-                                            self._retry_init_client_socket,
-                                            peer_ip, peer_port, connection_type)
+            self.alarm_queue.register_alarm(
+                self._get_next_retry_timeout(peer_ip, peer_port),
+                self._retry_init_client_socket,
+                peer_ip, peer_port, connection_type
+            )
         else:
-            self.on_failed_connection_retry(peer_ip, peer_port, connection_type)
+            self.on_failed_connection_retry(peer_ip, peer_port, connection_type, connection_state)
 
     def get_server_ssl_ctx(self) -> SSLContext:
         return self.node_ssl_service.create_ssl_context(SSLCertificateType.PRIVATE)
@@ -552,17 +585,12 @@ class AbstractNode:
         self.start_sync_time = time.time()
         self.sync_metrics = defaultdict(Counter)
 
-    def log_txs_network_content(
-        self, network_num: int, transaction_hash: Sha256Hash, transaction_contents: Union[bytearray, memoryview]
-    ) -> None:
+    @abstractmethod
+    def _transaction_sync_timeout(self) -> int:
         pass
 
     @abstractmethod
-    def _transaction_sync_timeout(self):
-        pass
-
-    @abstractmethod
-    def _check_sync_relay_connections(self):
+    def check_sync_relay_connections(self, conn: AbstractConnection) -> int:
         pass
 
     def _get_socket_peer_info(self, sock: AbstractSocketConnectionProtocol) -> AuthenticatedPeerInfo:
@@ -610,7 +638,9 @@ class AbstractNode:
         logger.debug("Breaking connection to {}. Attempting retry: {}", conn, should_retry)
         conn.dispose()
         self.connection_pool.delete(conn)
-        self.handle_connection_closed(should_retry, ConnectionPeerInfo(conn.endpoint, conn.CONNECTION_TYPE))
+        self.handle_connection_closed(
+            should_retry, ConnectionPeerInfo(conn.endpoint, conn.CONNECTION_TYPE), conn.state
+        )
 
     def _initialize_connection(
         self, socket_connection: AbstractSocketConnectionProtocol
@@ -633,8 +663,8 @@ class AbstractNode:
         return conn_obj
 
     def on_network_synced(self, network_num: int) -> None:
-        self.last_sync_message_received_by_network.pop(network_num, None)
-        self.network_synced[network_num] = True
+        if network_num in self.last_sync_message_received_by_network:
+            del self.last_sync_message_received_by_network[network_num]
 
     def on_fully_updated_tx_service(self):
         logger.debug(
