@@ -42,6 +42,7 @@ FULL_QUOTA_PERCENTAGE = 100
 NULL_TX_SID = 0
 NULL_TX_SIDS = {NULL_TX_SID}
 NULL_TX_TIMESTAMP = 0
+TX_SID_INTERVAL = 10000000
 UNKNOWN_TRANSACTION_HASH: Sha256Hash = Sha256Hash(bytearray(b"\xff" * crypto.SHA256_HASH_LEN))
 # </editor-fold>
 
@@ -59,7 +60,7 @@ CONNECTION_TIMEOUT = 3
 MAX_CONNECT_RETRIES = 3
 MAX_CONNECT_TIMEOUT_INCREASE = 7
 
-RECV_BUFSIZE = 65536
+RECV_BUFSIZE = 1024 * 1024
 MAX_BAD_MESSAGES = 3
 PING_INTERVAL_S = 60
 # </editor-fold>
@@ -131,7 +132,6 @@ class SdnRoutes:
     nodes = "/nodes"
     node = "/nodes/{0}"
     account = "/account/{0}"
-    gateway_node_config = "/configs/gateway_node/{0}"
     node_potential_relays_by_network = "/nodes/{0}/{1}/potential-relays"
     node_gateways = "/nodes/{0}/gateways?streaming={1}"
     node_remote_blockchain = "/nodes/{0}/potential-remote-blockchain-peers"
@@ -141,6 +141,7 @@ class SdnRoutes:
     gateway_inbound_connection = "/nodes/{0}/gateway-inbound-connection"
     bdn_services = "/configs/bdn-services"
     quota_status = "/accounts/quota-status"
+    gateway_settings = "/nodes/{0}/gateway-settings"
 
 
 # </editor-fold>
@@ -240,7 +241,7 @@ DEFAULT_BLOCK_HOLD_TIMEOUT = 0.3
 TXS_MSG_SIZE = 64000
 TXS_SYNC_TASK_DURATION = 0.15
 TX_SERVICE_SYNC_TXS_S = 0.01
-SENDING_TX_MSGS_TIMEOUT_S = 10 * 60
+SENDING_TX_MSGS_TIMEOUT_S = 15 * 60
 TX_SERVICE_CHECK_NETWORKS_SYNCED_S = 10 * 60
 LAST_MSG_FROM_RELAY_THRESHOLD_S = 30
 PING_TIMEOUT_S = 2
@@ -248,6 +249,7 @@ PING_TIMEOUT_S = 2
 NODE_LATENCY_THRESHOLD_MS = 2
 FASTEST_PING_LATENCY_THRESHOLD_PERCENT = 0.2
 UPDATE_TX_SERVICE_FULLY_SYNCED_S = 1
+FIRST_TX_SERVICE_SYNC_PROGRESS_S = 1
 TX_SERVICE_SYNC_PROGRESS_S = 10
 TX_SERVICE_SYNC_RELAY_IN_NETWORKS_S = 30
 
