@@ -14,7 +14,7 @@ class BdnPerformanceStatsMessage(AbstractBloxrouteMessage):
     """
 
     MSG_SIZE = AbstractBloxrouteMessage.HEADER_LENGTH + (2 * constants.DOUBLE_SIZE_IN_BYTES) + \
-               (2 * constants.UL_SHORT_SIZE_IN_BYTES) + (2 * constants.UL_INT_SIZE_IN_BYTES) \
+               (3 * constants.UL_SHORT_SIZE_IN_BYTES) + (2 * constants.UL_INT_SIZE_IN_BYTES) \
                + constants.CONTROL_FLAGS_LEN
     MESSAGE_TYPE = BloxrouteMessageType.BDN_PERFORMANCE_STATS
 
@@ -24,6 +24,7 @@ class BdnPerformanceStatsMessage(AbstractBloxrouteMessage):
     _new_blocks_received_from_bdn: Optional[int] = None
     _new_tx_received_from_blockchain_node: Optional[int] = None
     _new_tx_received_from_bdn: Optional[int] = None
+    _memory_utilization_mb: Optional[int] = None
 
     def __init__(
         self,
@@ -33,6 +34,7 @@ class BdnPerformanceStatsMessage(AbstractBloxrouteMessage):
         new_blocks_received_from_bdn: Optional[int] = None,
         new_tx_received_from_blockchain_node: Optional[int] = None,
         new_tx_received_from_bdn: Optional[int] = None,
+        memory_utilization_mb: Optional[int] = None,
         buf: Optional[bytearray] = None
     ):
         if buf is None:
@@ -42,6 +44,7 @@ class BdnPerformanceStatsMessage(AbstractBloxrouteMessage):
             assert new_blocks_received_from_bdn is not None
             assert new_tx_received_from_blockchain_node is not None
             assert new_tx_received_from_bdn is not None
+            assert memory_utilization_mb is not None
 
             buf = bytearray(self.MSG_SIZE)
 
@@ -64,11 +67,15 @@ class BdnPerformanceStatsMessage(AbstractBloxrouteMessage):
             struct.pack_into("<I", buf, off, new_tx_received_from_bdn)
             off += constants.UL_INT_SIZE_IN_BYTES
 
+            memory_utilization_mb = min(memory_utilization_mb, constants.UNSIGNED_SHORT_MAX_VALUE)
+            struct.pack_into("<H", buf, off, memory_utilization_mb)
+            off += constants.UL_SHORT_SIZE_IN_BYTES
+
         self.buf = buf
         payload_length = len(buf) - AbstractBloxrouteMessage.HEADER_LENGTH
         super().__init__(self.MESSAGE_TYPE, payload_length, self.buf)
 
-    def log_level(self):
+    def log_level(self) -> LogLevel:
         return LogLevel.DEBUG
 
     def interval_start_time(self) -> datetime:
@@ -119,6 +126,14 @@ class BdnPerformanceStatsMessage(AbstractBloxrouteMessage):
         assert new_tx_received_from_bdn is not None
         return new_tx_received_from_bdn
 
+    def memory_utilization(self) -> int:
+        if self._memory_utilization_mb is None:
+            self._unpack()
+
+        memory_utilization_mb = self._memory_utilization_mb
+        assert memory_utilization_mb is not None
+        return memory_utilization_mb
+
     def _unpack(self):
         off = AbstractBloxrouteMessage.HEADER_LENGTH
         self._interval_start_time, = struct.unpack_from("<d", self.buf, off)
@@ -133,9 +148,11 @@ class BdnPerformanceStatsMessage(AbstractBloxrouteMessage):
         off += constants.UL_INT_SIZE_IN_BYTES
         self._new_tx_received_from_bdn, = struct.unpack_from("<I", self.buf, off)
         off += constants.UL_INT_SIZE_IN_BYTES
+        self._memory_utilization_mb, = struct.unpack_from("<H", self.buf, off)
+        off += constants.UL_SHORT_SIZE_IN_BYTES
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return "BdnPerformanceStatsMessage<blocks_from_blockchain_node: {}, blocks_from_bdn: {}, " \
-               "tx_from_blockchain_node: {}, tx_from_bdn: {}>". \
+               "tx_from_blockchain_node: {}, tx_from_bdn: {}, memory_utilization: {}>". \
             format(self.new_blocks_from_blockchain_node(), self.new_blocks_from_bdn(),
-                   self.new_tx_from_blockchain_node(), self.new_tx_from_bdn())
+                   self.new_tx_from_blockchain_node(), self.new_tx_from_bdn(), self.memory_utilization())
