@@ -1,6 +1,7 @@
 from bxcommon.messages.bloxroute.bloxroute_message_type import BloxrouteMessageType
 from bxcommon.messages.bloxroute.v10.bdn_performance_stats_message_converter_v10 \
     import bdn_performance_stats_message_converter_v10
+from bxcommon.messages.bloxroute.v13.pong_message_converter_v13 import pong_message_converter_v13
 from bxcommon.messages.versioning.abstract_version_converter_factory import AbstractMessageConverterFactory
 from bxcommon.messages.versioning.no_changes_message_converter import no_changes_message_converter
 
@@ -8,6 +9,7 @@ from bxcommon.messages.versioning.no_changes_message_converter import no_changes
 class _MessageConverterFactoryV10(AbstractMessageConverterFactory):
     _MESSAGE_CONVERTER_MAPPING = {
         BloxrouteMessageType.BDN_PERFORMANCE_STATS: bdn_performance_stats_message_converter_v10,
+        BloxrouteMessageType.PONG: pong_message_converter_v13
     }
 
     def get_message_converter(self, msg_type):
