@@ -18,7 +18,7 @@ from bxcommon.messages.bloxroute.hello_message import HelloMessage
 from bxcommon.messages.bloxroute.key_message import KeyMessage
 from bxcommon.messages.bloxroute.notification_message import NotificationMessage
 from bxcommon.messages.bloxroute.ping_message import PingMessage
-from bxcommon.messages.bloxroute.pong_message import PongMessage
+from bxcommon.messages.bloxroute.v13.pong_message_v13 import PongMessageV13
 from bxcommon.messages.bloxroute.transaction_cleanup_message import TransactionCleanupMessage
 from bxcommon.messages.bloxroute.tx_contents_message import TxContentsMessage
 from bxcommon.messages.bloxroute.tx_message import TxMessage
@@ -51,7 +51,7 @@ class _BloxrouteMessageFactoryV9(AbstractMessageFactory):
         BloxrouteMessageType.HELLO: HelloMessage,
         BloxrouteMessageType.ACK: AckMessage,
         BloxrouteMessageType.PING: PingMessage,
-        BloxrouteMessageType.PONG: PongMessage,
+        BloxrouteMessageType.PONG: PongMessageV13,
         BloxrouteMessageType.BROADCAST: BroadcastMessage,
         BloxrouteMessageType.TRANSACTION: TxMessage,
         BloxrouteMessageType.GET_TRANSACTIONS: GetTxsMessage,
