@@ -42,3 +42,11 @@ class BlockchainNetworkModel:
     tx_sync_sync_content: bool = constants.GATEWAY_SYNC_SYNC_CONTENT
     enable_network_content_logs: bool = False
     enable_block_compression: bool = True
+    # Denoted in GWEI for Ethereum
+    min_tx_network_fee: int = 0
+    medium_tx_network_fee: int = 0
+    min_tx_age_seconds: float = 0.0
+
+    mempool_expected_transactions_count: int = 0
+    send_compressed_txs_after_block: bool = False
+    log_compressed_block_debug_info_on_relay: bool = True
