@@ -1,4 +1,4 @@
-class TransportLayerProtocol(object):
+class TransportLayerProtocol:
     """
     Transport Layer Protocols
 
@@ -6,4 +6,4 @@ class TransportLayerProtocol(object):
     """
 
     TCP = 6
-    UDP = 17
\ No newline at end of file
+    UDP = 17
