@@ -14,3 +14,6 @@ class RpcRequestType(SerializeableEnum):
     UNSUBSCRIBE = 9
     QUOTA_USAGE = 10
     MEMORY_USAGE = 11
+    TX_STATUS = 12
+    BLXR_ETH_CALL = 13
+    TX_SERVICE = 14
