@@ -1,17 +1,15 @@
 import struct
-import time
 from datetime import datetime
-from typing import Any, List, Union, Optional
+from typing import Any, List, Union, Optional, cast
 
 import task_pool_executor as tpe
 
 from bxcommon import constants
-from bxcommon.messages.bloxroute import transactions_info_serializer, short_ids_serializer
-from bxcommon.models.transaction_info import TransactionSearchResult
-from bxcommon.services.transaction_service import TransactionService, TransactionCacheKeyType, \
-    TransactionFromBdnGatewayProcessingResult
+from bxcommon.messages.bloxroute import transactions_info_serializer
+from bxcommon.models.transaction_info import TransactionSearchResult, TransactionInfo
+from bxcommon.services.transaction_service import TransactionService, TransactionCacheKeyType
 from bxcommon.services.transaction_service import TxRemovalReason
-from bxcommon.utils import memory_utils
+from bxcommon.utils import memory_utils, crypto
 from bxcommon.utils.object_encoder import ObjectEncoder
 from bxcommon.utils.object_hash import Sha256Hash
 from bxcommon.utils.proxy import task_pool_proxy
@@ -38,6 +36,7 @@ class ExtensionTransactionService(TransactionService):
 
         self.proxy = tpe.TransactionService(
             task_pool_proxy.get_pool_size(),
+            self.node.opts.blockchain_networks[network_num].protocol.lower(),
             node.opts.tx_mem_pool_bucket_size,
             self._get_final_tx_confirmations_count()
         )
@@ -56,10 +55,6 @@ class ExtensionTransactionService(TransactionService):
         )
         self._tx_not_seen_in_blocks = self.proxy.tx_not_seen_in_blocks()
 
-        self._tx_hash_to_time_removed = MapProxy(
-            self.proxy.tx_hash_to_time_removed(), raw_encoder, raw_encoder
-        )
-
     def track_seen_short_ids(self, block_hash, short_ids: List[int]) -> None:
         start_datetime = datetime.now()
         super(ExtensionTransactionService, self).track_seen_short_ids(block_hash, short_ids)
@@ -109,16 +104,25 @@ class ExtensionTransactionService(TransactionService):
             if self.node.opts.dump_removed_short_ids:
                 self._removed_short_ids.add(short_id)
 
-    def assign_short_id(self, transaction_hash: Sha256Hash, short_id: int):
+    def assign_short_id(
+        self,
+        transaction_hash: Sha256Hash,
+        short_id: int,
+        transaction_cache_key: Optional[TransactionCacheKeyType] = None
+    ) -> None:
         """
         Adds short id mapping for transaction and schedules an alarm to cleanup entry on expiration.
         :param transaction_hash: transaction long hash
         :param short_id: short id to be mapped to transaction
+        :param transaction_cache_key: transaction cache key
         """
         logger.trace("Assigning sid {} to transaction {}", short_id, transaction_hash)
-        tx_cache_key = self._tx_hash_to_cache_key(transaction_hash)
-        has_contents = self.proxy.assign_short_id(tx_cache_key, short_id)
-        self.assign_short_id_base(transaction_hash, tx_cache_key, short_id, has_contents, False)
+        if not transaction_cache_key:
+            transaction_cache_key = self._tx_hash_to_cache_key(transaction_hash)
+
+        transaction_cache_key = cast(tpe.Sha256, transaction_cache_key)
+        has_contents = self.proxy.assign_short_id(transaction_cache_key, short_id)
+        self.assign_short_id_base(transaction_hash, transaction_cache_key, short_id, has_contents, False)
 
     def set_transaction_contents(
         self, transaction_hash: Sha256Hash, transaction_contents: Union[bytearray, memoryview],
@@ -145,7 +149,7 @@ class ExtensionTransactionService(TransactionService):
             has_short_id,
             previous_size,
             False,
-            None,
+            transaction_contents,
             len(transaction_contents)
         )
 
@@ -174,59 +178,29 @@ class ExtensionTransactionService(TransactionService):
         found_txs_info = transactions_info_serializer \
             .deserialize_transactions_info(txs_bytes)
 
-        missing_short_ids = short_ids_serializer \
-            .deserialize_short_ids(result_memory_view[constants.UL_INT_SIZE_IN_BYTES + found_txs_size:])
+        missing_txs_info = []
+        offset = constants.UL_INT_SIZE_IN_BYTES + found_txs_size
 
-        return TransactionSearchResult(found_txs_info, missing_short_ids)
+        missing_txs_count, = struct.unpack_from("<L", result_memory_view, offset)
+        offset += constants.UL_INT_SIZE_IN_BYTES
 
-    def process_gateway_transaction_from_bdn(
-        self,
-        transaction_hash: Sha256Hash,
-        short_id: int,
-        transaction_contents: Union[bytearray, memoryview],
-        is_compact: bool
-    ) -> TransactionFromBdnGatewayProcessingResult:
+        for _ in range(missing_txs_count):
+            tx_sid, = struct.unpack_from("<L", result_memory_view, offset)
+            offset += constants.UL_INT_SIZE_IN_BYTES
 
-        transaction_cache_key = self._tx_hash_to_cache_key(transaction_hash)
+            has_hash, = struct.unpack_from("<B", result_memory_view, offset)
+            offset += constants.UL_TINY_SIZE_IN_BYTES
 
-        ext_result = self.proxy.process_gateway_transaction_from_bdn(
-            transaction_cache_key,
-            tpe.InputBytes(transaction_contents),
-            short_id,
-            is_compact
-        )
+            if has_hash:
+                tx_hash = Sha256Hash(result_memory_view[offset:offset + crypto.SHA256_HASH_LEN])
+                offset += crypto.SHA256_HASH_LEN
+            else:
+                tx_hash = None
 
-        result = TransactionFromBdnGatewayProcessingResult(
-            ext_result.get_ignore_seen(),
-            ext_result.get_existing_short_id(),
-            ext_result.get_assigned_short_id(),
-            ext_result.get_existing_contents(),
-            ext_result.get_set_contents()
-        )
+            missing_txs_info.append(TransactionInfo(tx_hash, None, tx_sid))
 
-        if result.set_content:
-            has_short_id, previous_size = ext_result.get_set_contents_result()
-            self.set_transaction_contents_base(
-                transaction_hash,
-                transaction_cache_key,
-                has_short_id,
-                previous_size,
-                False,
-                None,
-                len(transaction_contents)
-            )
+        return TransactionSearchResult(found_txs_info, missing_txs_info)
 
-        if result.assigned_short_id:
-            has_contents = result.existing_contents or result.set_content
-            self.assign_short_id_base(
-                transaction_hash,
-                transaction_cache_key,
-                short_id,
-                has_contents,
-                False
-            )
-
-        return result
 
     def log_tx_service_mem_stats(self):
         super(ExtensionTransactionService, self).log_tx_service_mem_stats()
@@ -255,8 +229,10 @@ class ExtensionTransactionService(TransactionService):
                     len(self._short_id_to_tx_cache_key) * constants.UL_INT_SIZE_IN_BYTES)
             return memory_utils.ObjectSize(size=collection_size, flat_size=0, is_actual_size=True)
         else:
-            return super(ExtensionTransactionService, self).get_collection_mem_stats(collection_obj,
-                                                                                     estimated_size)
+            return super(ExtensionTransactionService, self).get_collection_mem_stats(
+                collection_obj,
+                estimated_size
+            )
 
     def get_object_type(self, collection_obj: Any):
         super(ExtensionTransactionService, self).get_object_type(collection_obj)
@@ -314,26 +290,11 @@ class ExtensionTransactionService(TransactionService):
                                                                                     force=force,
                                                                                     removal_reason=removal_reason)
 
-    def _clear(self):
-        super(ExtensionTransactionService, self)._clear()
-        self.proxy.clear_short_ids_seen_in_block()
+    def clear(self):
+        self.proxy.clear()
 
-    def _cleanup_removed_transactions_history(self):
-        logger.trace(
-            "Starting to cleanup transaction cache history for network "
-            "number: {}.",
-            self.network_num
-        )
-        history_len_before = len(self._tx_hash_to_time_removed)
-        self._tx_hash_to_time_removed.map_obj.cleanup_removed_hashes_history(
-            time.time(), self._removed_txs_expiration_time_s, constants.REMOVED_TRANSACTIONS_HISTORY_LENGTH_LIMIT
-        )
-        history_len_after = len(self._tx_hash_to_time_removed)
-        logger.trace(
-            "Finished cleanup transaction cache history. Size before: {}. "
-            "Size after: {}.",
-            history_len_before,
-            history_len_after
-        )
-
-        return constants.REMOVED_TRANSACTIONS_HISTORY_CLEANUP_INTERVAL_S
+        self._short_id_to_tx_quota_flag.clear()
+        self.tx_hashes_without_content.clear()
+        self.tx_hashes_without_short_id.clear()
+        self._tx_assignment_expire_queue.clear()
+        self._total_tx_contents_size = 0
