@@ -1,9 +1,11 @@
+from asyncio import Future
 from typing import List, Optional
 
 from mock import MagicMock
 
 from bxcommon.connections.abstract_connection import AbstractConnection
 from bxcommon.connections.abstract_node import AbstractNode
+from bxcommon.connections.connection_state import ConnectionState
 from bxcommon.connections.connection_type import ConnectionType
 from bxcommon.constants import DEFAULT_NETWORK_NUM
 from bxcommon.models.node_type import NodeType
@@ -50,22 +52,27 @@ class MockNode(AbstractNode):
     def get_broadcast_service(self) -> BroadcastService:
         pass
 
-    def send_request_for_relay_peers(self):
+    def sync_and_send_request_for_relay_peers(self, network_num: int):
         pass
 
     def build_connection(self, socket_connection: AbstractSocketConnectionProtocol) -> Optional[AbstractConnection]:
         pass
 
-    def on_failed_connection_retry(self, ip: str, port: int, connection_type: ConnectionType) -> None:
+    def process_potential_relays_from_sdn(self, get_potential_relays_future: Future):
+        pass
+
+    def on_failed_connection_retry(
+        self, ip: str, port: int, connection_type: ConnectionType, connection_state: ConnectionState
+    ) -> None:
         pass
 
     def sync_tx_services(self):
         pass
 
-    def _transaction_sync_timeout(self):
+    def _transaction_sync_timeout(self) -> int:
         pass
 
-    def _check_sync_relay_connections(self):
+    def check_sync_relay_connections(self, conn: AbstractConnection) -> int:
         pass
 
     def broadcast_transaction(
