@@ -18,3 +18,5 @@ CONFIGURATION_ERROR = "Error setting up or reading configuration"
 GENERAL_WARNING = "General warning category"
 AUTHENTICATION_ERROR = "Authentication error"
 RPC_ERROR = "Rpc error"
+AUDITING_ERROR = "Auditing error"
+NOTIFICATION_FROM_RELAY_CATEGORY = "Notification from relay"
\ No newline at end of file
