@@ -2,6 +2,7 @@ import logging
 from io import BytesIO
 
 import msgpack
+import sys
 
 from bxutils import constants
 from bxutils import log_messages
@@ -10,11 +11,11 @@ from bxutils.logging.fluentd_overflow_handler_type import OverflowHandlerType
 logger = logging.getLogger(__name__)
 
 
-def overflow_handler_print(pending_records_buffer):
+def overflow_handler_print(pending_records_buffer, file_obj=sys.stdout):
     logger.error(log_messages.FLUENTD_LOGGER_BUFFER_OVERFLOW)
     unpacker = msgpack.Unpacker(BytesIO(pending_records_buffer))
     for unpacked in unpacker:
-        print(unpacked)
+        print(unpacked, file=file_obj)
 
 
 def overflow_handler_ignore(_pending_records_buffer):
