@@ -1,6 +1,7 @@
 from typing import NamedTuple, Union, Dict, Any
 
 from bxcommon.utils.object_hash import Sha256Hash
+from bxgateway.feed.new_transaction_feed import FeedSource
 
 
 class EthRawTransaction(NamedTuple):
@@ -14,4 +15,5 @@ class EthRawTransaction(NamedTuple):
     Raw pre-serialized transaction must be able to handle all cases.
     """
     tx_hash: Sha256Hash
-    tx_contents: Union[memoryview, Dict[str, Any]]
\ No newline at end of file
+    tx_contents: Union[memoryview, Dict[str, Any]]
+    source: FeedSource
