@@ -12,6 +12,9 @@ from bxcommon.rpc.rpc_errors import RpcInvalidParams, RpcAccountIdError
 from bxcommon.utils.stats import stats_format
 from bxcommon.utils.stats.transaction_stat_event_type import TransactionStatEventType
 from bxcommon.utils.stats.transaction_statistics_service import tx_stats
+from bxcommon.models.blockchain_protocol import BlockchainProtocol
+from bxcommon.messages.eth.serializers.transaction import Transaction
+
 from bxutils import logging, log_messages as common_log_messages
 
 if TYPE_CHECKING:
@@ -35,6 +38,22 @@ class GatewayBlxrTransactionRpcRequest(AbstractBlxrTransactionRpcRequest["Abstra
         self.synchronous = \
             params.get(self.SYNCHRONOUS, lowercase_true).lower() == lowercase_true
 
+    def validate_params(self) -> None:
+        params = self.params
+        if params is None or not isinstance(params, dict):
+            raise RpcInvalidParams(
+                self.request_id,
+                "Params request field is either missing or not a dictionary type."
+            )
+        if (
+            rpc_constants.TRANSACTION_JSON_PARAMS_KEY in params
+            and self.get_network_protocol() == BlockchainProtocol.ETHEREUM
+        ):
+            tx_json = params[rpc_constants.TRANSACTION_JSON_PARAMS_KEY]
+            tx_bytes = Transaction.from_json_with_validation(tx_json).contents().tobytes()
+            params[rpc_constants.TRANSACTION_PARAMS_KEY] = tx_bytes.hex()
+        super(GatewayBlxrTransactionRpcRequest, self).validate_params()
+
     async def process_request(self) -> JsonRpcResponse:
         params = self.params
         assert isinstance(params, dict)
@@ -90,7 +109,7 @@ class GatewayBlxrTransactionRpcRequest(AbstractBlxrTransactionRpcRequest["Abstra
             )
         tx_service = self.node.get_tx_service()
         tx_hash = bx_tx.tx_hash()
-        if tx_service.has_transaction_contents(tx_hash) or tx_service.removed_transaction(tx_hash):
+        if tx_service.has_transaction_contents(tx_hash):
             short_id = tx_service.get_short_id(tx_hash)
             tx_stats.add_tx_by_hash_event(
                 tx_hash,
@@ -110,6 +129,10 @@ class GatewayBlxrTransactionRpcRequest(AbstractBlxrTransactionRpcRequest["Abstra
             network_num,
             account_id=account_id
         )
+        if self.node.node_conn is not None:
+            blockchain_tx_message = self.node.message_converter.bx_tx_to_tx(bx_tx)
+            self.node.send_msg_to_node(blockchain_tx_message)
+
         # All connections outside of this one is a bloXroute server
         broadcast_peers = self.node.broadcast(bx_tx, connection_types=[ConnectionType.RELAY_TRANSACTION])
         tx_stats.add_tx_by_hash_event(
@@ -136,3 +159,7 @@ class GatewayBlxrTransactionRpcRequest(AbstractBlxrTransactionRpcRequest["Abstra
 
     def get_account_id(self) -> str:
         return self.node.account_id
+
+    def get_network_protocol(self) -> BlockchainProtocol:
+        blockchain_protocol = self.node.opts.blockchain_protocol
+        return blockchain_protocol
