@@ -14,6 +14,7 @@ from bxcommon.utils.stats import hooks
 from bxcommon.utils.stats.block_stat_event_type import BlockStatEventType
 from bxcommon.utils.stats.block_statistics_service import block_stats
 from bxgateway import gateway_constants
+from bxgateway.feed.feed_source import FeedSource
 from bxgateway.messages.eth.internal_eth_block_info import InternalEthBlockInfo
 from bxgateway.messages.eth.new_block_parts import NewBlockParts
 from bxgateway.messages.eth.protocol.block_bodies_eth_protocol_message import (
@@ -160,6 +161,9 @@ class EthBlockQueuingService(
             raise ValueError(f"Block with hash {block_hash} already exists in the queue.")
 
         if not self.can_add_block_to_queuing_service(block_hash):
+            logger.debug(
+                "Skipping adding {} to queue. Block already seen.", block_hash
+            )
             return
 
         if waiting_for_recovery:
@@ -213,6 +217,9 @@ class EthBlockQueuingService(
             return
 
         if self._check_for_sent_or_queued_forked_block(block_hash, block_number):
+            logger.debug(
+                "Discarding recovered block."
+            )
             return
 
         position = self._ordered_insert(block_hash, block_number, time.time())
@@ -268,6 +275,10 @@ class EthBlockQueuingService(
         best_height, _ = self.best_accepted_block
         if block_number >= best_height:
             self.best_accepted_block = EthBlockInfo(block_number, block_hash)
+            if block_message or block_hash in self._block_parts:
+                self.node.publish_block(
+                    block_number, block_hash, block_message, FeedSource.BLOCKCHAIN_SOCKET
+                )
 
         if block_hash in self.block_checking_alarms:
             self.node.alarm_queue.unregister_alarm(
@@ -317,7 +328,7 @@ class EthBlockQueuingService(
                 block_hash, new_block_msg
             )
             self.node.set_known_total_difficulty(
-                new_block_msg.block_hash(), new_block_msg.chain_difficulty()
+                new_block_msg.block_hash(), new_block_msg.get_chain_difficulty()
             )
         else:
             calculated_total_difficulty = self.node.try_calculate_total_difficulty(
@@ -348,6 +359,9 @@ class EthBlockQueuingService(
         self.best_sent_block = SentEthBlockInfo(block_number, block_hash, time.time())
         self._schedule_confirmation_check(block_hash)
 
+        if self.node.opts.filter_txs_factor > 0:
+            self.node.on_transactions_in_block(block_msg.to_new_block_msg().txns())
+
     def partial_chainstate(self, required_length: int) -> Deque[EthBlockInfo]:
         """
         Builds a current chainstate based on the current head. Attempts to maintain
@@ -491,7 +505,7 @@ class EthBlockQueuingService(
 
         Returns (success, [found_hashes])
         """
-        if block_hash not in self._blocks:
+        if block_hash not in self._blocks or self._blocks[block_hash] is None:
             return False, []
 
         if block_hash in self._blocks_waiting_for_recovery and self._blocks_waiting_for_recovery[block_hash]:
@@ -726,7 +740,7 @@ class EthBlockQueuingService(
 
         self.node.send_msg_to_node(get_confirmation_message)
 
-        if self.block_check_repeat_count[block_hash] < 5:
+        if self.block_check_repeat_count[block_hash] < eth_common_constants.CHECK_BLOCK_RECEIPT_MAX_COUNT:
             self.block_check_repeat_count[block_hash] += 1
             return eth_common_constants.CHECK_BLOCK_RECEIPT_INTERVAL_S
         else:
@@ -771,7 +785,7 @@ class EthBlockQueuingService(
             self._try_immediate_send(block_hash, block_number, block_msg)
             _best_height, _best_hash, sent_time = self.best_sent_block
             elapsed_time = time.time() - sent_time
-            timeout = self.node.opts.max_block_interval - elapsed_time
+            timeout = self.node.opts.max_block_interval_s - elapsed_time
             self._run_or_schedule_alarm(timeout, self._send_top_block_to_node)
             break
 
@@ -831,6 +845,8 @@ class EthBlockQueuingService(
             block_hash
         )
         self.remove_from_queue(block_hash)
+        if block_hash in self._blocks and self._blocks[block_hash] is None:
+            self.remove(block_hash)
 
     def _check_for_sent_or_queued_forked_block(self, block_hash: Sha256Hash, block_number: int) -> bool:
         """
@@ -962,6 +978,8 @@ class EthBlockQueuingService(
             )
             self.send_block_to_node(block_hash, block_msg)
             self.remove_from_queue(block_hash)
+            self.node.publish_block(
+                block_number, block_hash, block_msg, FeedSource.BDN_SOCKET
+            )
             return True
         return False
-
